==> qorewidgets-0.2.1.tar.gz: qorewidgets-0.2.1/src/QoreWidgets/rc.py <==
# Resource object code (Python 3)
# Created by: object code
# Created by: The Resource Compiler for Qt version 6.7.2
# WARNING! All changes made in this file will be lost!

from PySide6 import QtCore

qt_resource_data = b"\
\x00\x00\x01\xc1\
<\
svg xmlns=\x22http:\
//www.w3.org/200\
0/svg\x22 height=\x222\
4px\x22 viewBox=\x220 \
-960 960 960\x22 wi\
dth=\x2224px\x22 fill=\
\x22#5f6368\x22><path \
d=\x22M480-80q-82 0\
-155-31.5t-127.5\
-86Q143-252 111.\
5-325T80-480q0-8\
3 31.5-155.5t86-\
127Q252-817 325-\
848.5T480-880q17\
 0 28.5 11.5T520\
-840q0 17-11.5 2\
8.5T480-800q-133\
 0-226.5 93.5T16\
0-480q0 133 93.5\
 226.5T480-160q1\
33 0 226.5-93.5T\
800-480q0-17 11.\
5-28.5T840-520q1\
7 0 28.5 11.5T88\
0-480q0 82-31.5 \
155t-86 127.5q-5\
4.5 54.5-127 86T\
480-80Z\x22/></svg>\
\
\x00\x00\x00\xde\
<\
svg xmlns=\x22http:\
//www.w3.org/200\
0/svg\x22 height=\x222\
4px\x22 viewBox=\x220 \
-960 960 960\x22 wi\
dth=\x2224px\x22 fill=\
\x22#5f6368\x22><path \
d=\x22m256-200-56-5\
6 224-224-224-22\
4 56-56 224 224 \
224-224 56 56-22\
4 224 224 224-56\
 56-224-224-224 \
224Z\x22/></svg>\
\x00\x00\x00\xc1\
<\
svg xmlns=\x22http:\
//www.w3.org/200\
0/svg\x22 height=\x222\
4px\x22 viewBox=\x220 \
-960 960 960\x22 wi\
dth=\x2224px\x22 fill=\
\x22#5f6368\x22><path \
d=\x22M120-240v-80h\
720v80H120Zm0-20\
0v-80h720v80H120\
Zm0-200v-80h720v\
80H120Z\x22/></svg>\
\
\x00\x00\x01\x1f\
<\
svg xmlns=\x22http:\
//www.w3.org/200\
0/svg\x22 height=\x222\
4px\x22 viewBox=\x22-1\
00 -1060 1160 11\
60\x22 width=\x2224px\x22\
 fill=\x22#5f6368\x22>\
<path d=\x22M200-12\
0q-33 0-56.5-23.\
5T120-200v-560q0\
-33 23.5-56.5T20\
0-840h560q33 0 5\
6.5 23.5T840-760\
v560q0 33-23.5 5\
6.5T760-120H200Z\
m0-80h560v-560H2\
00v560Zm0 0v-560\
 560Z\x22/></svg>\
\x00\x00\x00\x95\
<\
svg xmlns=\x22http:\
//www.w3.org/200\
0/svg\x22 height=\x222\
4px\x22 viewBox=\x220 \
-960 960 960\x22 wi\
dth=\x2224px\x22 fill=\
\x22#5f6368\x22><path \
d=\x22M160-440v-80h\
640v80H160Z\x22/></\
svg>\
\x00\x00\x01X\
<\
svg xmlns=\x22http:\
//www.w3.org/200\
0/svg\x22 height=\x222\
4px\x22 viewBox=\x22-1\
00 -1060 1160 11\
60\x22 width=\x2224px\x22\
 fill=\x22#5f6368\x22>\
<path d=\x22M320-24\
0q-33 0-56.5-23.\
5T240-320v-480q0\
-33 23.5-56.5T32\
0-880h480q33 0 5\
6.5 23.5T880-800\
v480q0 33-23.5 5\
6.5T800-240H320Z\
m0-80h480v-480H3\
20v480ZM160-80q-\
33 0-56.5-23.5T8\
0-160v-560h80v56\
0h560v80H160Zm16\
0-720v480-480Z\x22/\
></svg>\
"

qt_resource_name = b"\
\x00\x05\
\x00o\xa6S\
\x00i\
\x00c\x00o\x00n\x00s\
\x00\x07\
\x03W\xb0\xa7\
\x00l\
\x00o\x00a\x00d\x00i\x00n\x00g\
\x00\x05\
\x00j6\x95\
\x00c\
\x00l\x00o\x00s\x00e\
\x00\x04\
\x00\x07<U\
\x00m\
\x00e\x00n\x00u\
\x00\x08\
\x08\xf0Oe\
\x00m\
\x00a\x00x\x00i\x00m\x00i\x00z\x00e\
\x00\x08\
\x00PO\x85\
\x00m\
\x00i\x00n\x00i\x00m\x00i\x00z\x00e\
\x00\x07\
\x08\xca\xb6e\
\x00r\
\x00e\x00s\x00t\x00o\x00r\x00e\
"

qt_resource_struct = b"\
\x00\x00\x00\x00\x00\x02\x00\x00\x00\x01\x00\x00\x00\x01\
\x00\x00\x00\x00\x00\x00\x00\x00\
\x00\x00\x00\x00\x00\x02\x00\x00\x00\x06\x00\x00\x00\x02\
\x00\x00\x00\x00\x00\x00\x00\x00\
\x00\x00\x004\x00\x00\x00\x00\x00\x01\x00\x00\x02\xa7\
\x00\x00\x01\x91'\x90\x1bp\
\x00\x00\x00X\x00\x00\x00\x00\x00\x01\x00\x00\x04\x8f\
\x00\x00\x01\x91I\xbd\x0a\x89\
\x00\x00\x00$\x00\x00\x00\x00\x00\x01\x00\x00\x01\xc5\
\x00\x00\x01\x91GH\x05\x05\
\x00\x00\x00\x10\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\
\x00\x00\x01\x91\x948\x94\xfd\
\x00\x00\x00n\x00\x00\x00\x00\x00\x01\x00\x00\x05(\
\x00\x00\x01\x91K\xa9\xf37\
\x00\x00\x00B\x00\x00\x00\x00\x00\x01\x00\x00\x03l\
\x00\x00\x01\x91I\xc1\x9d\x7f\
"

def qInitResources():
    QtCore.qRegisterResourceData(0x03, qt_resource_struct, qt_resource_name, qt_resource_data)

def qCleanupResources():
    QtCore.qUnregisterResourceData(0x03, qt_resource_struct, qt_resource_name, qt_resource_data)

qInitResources()

==> qorewidgets-0.2.2.tar.gz: qorewidgets-0.2.2/src/QoreWidgets/rc.py <==
# Resource object code (Python 3)
# Created by: object code
# Created by: The Resource Compiler for Qt version 6.7.3
# WARNING! All changes made in this file will be lost!

from PySide6 import QtCore

qt_resource_data = b"\
\x00\x00\x01\xc1\
<\
svg xmlns=\x22http:\
//www.w3.org/200\
0/svg\x22 height=\x222\
4px\x22 viewBox=\x220 \
-960 960 960\x22 wi\
dth=\x2224px\x22 fill=\
\x22#5f6368\x22><path \
d=\x22M480-80q-82 0\
-155-31.5t-127.5\
-86Q143-252 111.\
5-325T80-480q0-8\
3 31.5-155.5t86-\
127Q252-817 325-\
848.5T480-880q17\
 0 28.5 11.5T520\
-840q0 17-11.5 2\
8.5T480-800q-133\
 0-226.5 93.5T16\
0-480q0 133 93.5\
 226.5T480-160q1\
33 0 226.5-93.5T\
800-480q0-17 11.\
5-28.5T840-520q1\
7 0 28.5 11.5T88\
0-480q0 82-31.5 \
155t-86 127.5q-5\
4.5 54.5-127 86T\
480-80Z\x22/></svg>\
\
\x00\x00\x00\xde\
<\
svg xmlns=\x22http:\
//www.w3.org/200\
0/svg\x22 height=\x222\
4px\x22 viewBox=\x220 \
-960 960 960\x22 wi\
dth=\x2224px\x22 fill=\
\x22#5f6368\x22><path \
d=\x22m256-200-56-5\
6 224-224-224-22\
4 56-56 224 224 \
224-224 56 56-22\
4 224 224 224-56\
 56-224-224-224 \
224Z\x22/></svg>\
\x00\x00\x00\xc1\
<\
svg xmlns=\x22http:\
//www.w3.org/200\
0/svg\x22 height=\x222\
4px\x22 viewBox=\x220 \
-960 960 960\x22 wi\
dth=\x2224px\x22 fill=\
\x22#5f6368\x22><path \
d=\x22M120-240v-80h\
720v80H120Zm0-20\
0v-80h720v80H120\
Zm0-200v-80h720v\
80H120Z\x22/></svg>\
\
\x00\x00\x02\x1e\
<\
svg xmlns=\x22http:\
//www.w3.org/200\
0/svg\x22 height=\x222\
4px\x22 viewBox=\x220 \
-960 960 960\x22 wi\
dth=\x2224px\x22 fill=\
\x22#5f6368\x22><path \
d=\x22m791-55-91-91\
q-49 32-104.5 49\
T480-80q-83 0-15\
6-31.5T197-197q-\
54-54-85.5-127T8\
0-480q0-60 17-11\
5.5T146-700l-91-\
91 57-57 736 736\
-57 57ZM480-160q\
43 0 83.5-11t78.\
5-33L204-642q-22\
 38-33 78.5T160-\
480q0 133 93.5 2\
26.5T480-160Zm33\
4-100-58-58q22-3\
8 33-78.5t11-83.\
5q0-133-93.5-226\
.5T480-800q-43 0\
-83.5 11T318-756\
l-58-58q49-32 10\
4.5-49T480-880q8\
3 0 156 31.5T763\
-763q54 54 85.5 \
127T880-480q0 60\
-17 115.5T814-26\
0ZM537-537ZM423-\
423Z\x22/></svg>\
\x00\x00\x01\x1f\
<\
svg xmlns=\x22http:\
//www.w3.org/200\
0/svg\x22 height=\x222\
4px\x22 viewBox=\x22-1\
00 -1060 1160 11\
60\x22 width=\x2224px\x22\
 fill=\x22#5f6368\x22>\
<path d=\x22M200-12\
0q-33 0-56.5-23.\
5T120-200v-560q0\
-33 23.5-56.5T20\
0-840h560q33 0 5\
6.5 23.5T840-760\
v560q0 33-23.5 5\
6.5T760-120H200Z\
m0-80h560v-560H2\
00v560Zm0 0v-560\
 560Z\x22/></svg>\
\x00\x00\x00\x95\
<\
svg xmlns=\x22http:\
//www.w3.org/200\
0/svg\x22 height=\x222\
4px\x22 viewBox=\x220 \
-960 960 960\x22 wi\
dth=\x2224px\x22 fill=\
\x22#5f6368\x22><path \
d=\x22M160-440v-80h\
640v80H160Z\x22/></\
svg>\
\x00\x00\x01X\
<\
svg xmlns=\x22http:\
//www.w3.org/200\
0/svg\x22 height=\x222\
4px\x22 viewBox=\x22-1\
00 -1060 1160 11\
60\x22 width=\x2224px\x22\
 fill=\x22#5f6368\x22>\
<path d=\x22M320-24\
0q-33 0-56.5-23.\
5T240-320v-480q0\
-33 23.5-56.5T32\
0-880h480q33 0 5\
6.5 23.5T880-800\
v480q0 33-23.5 5\
6.5T800-240H320Z\
m0-80h480v-480H3\
20v480ZM160-80q-\
33 0-56.5-23.5T8\
0-160v-560h80v56\
0h560v80H160Zm16\
0-720v480-480Z\x22/\
></svg>\
"

qt_resource_name = b"\
\x00\x05\
\x00o\xa6S\
\x00i\
\x00c\x00o\x00n\x00s\
\x00\x07\
\x03W\xb0\xa7\
\x00l\
\x00o\x00a\x00d\x00i\x00n\x00g\
\x00\x05\
\x00j6\x95\
\x00c\
\x00l\x00o\x00s\x00e\
\x00\x04\
\x00\x07<U\
\x00m\
\x00e\x00n\x00u\
\x00\x05\
\x00lG\xb9\
\x00e\
\x00m\x00p\x00t\x00y\
\x00\x08\
\x08\xf0Oe\
\x00m\
\x00a\x00x\x00i\x00m\x00i\x00z\x00e\
\x00\x08\
\x00PO\x85\
\x00m\
\x00i\x00n\x00i\x00m\x00i\x00z\x00e\
\x00\x07\
\x08\xca\xb6e\
\x00r\
\x00e\x00s\x00t\x00o\x00r\x00e\
"

qt_resource_struct = b"\
\x00\x00\x00\x00\x00\x02\x00\x00\x00\x01\x00\x00\x00\x01\
\x00\x00\x00\x00\x00\x00\x00\x00\
\x00\x00\x00\x00\x00\x02\x00\x00\x00\x07\x00\x00\x00\x02\
\x00\x00\x00\x00\x00\x00\x00\x00\
\x00\x00\x004\x00\x00\x00\x00\x00\x01\x00\x00\x02\xa7\
\x00\x00\x01\x92V5\xa4\xd0\
\x00\x00\x00h\x00\x00\x00\x00\x00\x01\x00\x00\x06\xb1\
\x00\x00\x01\x92V5\xa4\xd0\
\x00\x00\x00$\x00\x00\x00\x00\x00\x01\x00\x00\x01\xc5\
\x00\x00\x01\x92V5\xa4\xd0\
\x00\x00\x00B\x00\x00\x00\x00\x00\x01\x00\x00\x03l\
\x00\x00\x01\x92VHo\xe6\
\x00\x00\x00\x10\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\
\x00\x00\x01\x92V5\xa4\xd0\
\x00\x00\x00~\x00\x00\x00\x00\x00\x01\x00\x00\x07J\
\x00\x00\x01\x92V5\xa4\xd0\
\x00\x00\x00R\x00\x00\x00\x00\x00\x01\x00\x00\x05\x8e\
\x00\x00\x01\x92V5\xa4\xd0\
"

def qInitResources():
    QtCore.qRegisterResourceData(0x03, qt_resource_struct, qt_resource_name, qt_resource_data)

def qCleanupResources():
    QtCore.qUnregisterResourceData(0x03, qt_resource_struct, qt_resource_name, qt_resource_data)

qInitResources()
